@@ -12,7 +12,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -57,7 +57,7 @@ Int vex_debuglevel = 0;
 Int vex_traceflags = 0;
 
 /* Max # guest insns per bb */
-VexControl vex_control = { 0,0,False,0,0,0 };
+VexControl vex_control = { 0,0,VexRegUpd_INVALID,0,0,False,0,False };
 
 
 
