@@ -12,7 +12,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -131,7 +131,10 @@ typedef
 
       /* Emulation notes */
       UInt  guest_EMNOTE;
-      UInt  pad2;
+      /* Used by Darwin and FreeBSD when setting the carry flag from
+       * ML_(do_syscall_for_client_WRK). Needed to determine how
+       * to restart interrupted syscalls. */
+      UInt guest_SETC;
 
       /* Translation-invalidation area description.  Not used on amd64
          (there is no invalidate-icache insn), but needed so as to
@@ -167,8 +170,11 @@ typedef
          been interrupted by a signal. */
       ULong guest_IP_AT_SYSCALL;
 
-      /* Padding to make it have an 16-aligned size */
-      ULong pad3;
+      /* Used on FreeBSD as part of a mechanism to allow signal handlers
+           to use TLS. */
+      ULong guest_TLSBASE;
+
+      /* Add padding here to make it have an 16-aligned size */
    }
    VexGuestAMD64State;
 
