@@ -165,3 +165,69 @@
 #define OFFSET_mips64_PC 272
 #define OFFSET_mips64_HI 280
 #define OFFSET_mips64_LO 288
+#define OFFSET_riscv64_x0 16
+#define OFFSET_riscv64_x1 24
+#define OFFSET_riscv64_x2 32
+#define OFFSET_riscv64_x3 40
+#define OFFSET_riscv64_x4 48
+#define OFFSET_riscv64_x5 56
+#define OFFSET_riscv64_x6 64
+#define OFFSET_riscv64_x7 72
+#define OFFSET_riscv64_x8 80
+#define OFFSET_riscv64_x9 88
+#define OFFSET_riscv64_x10 96
+#define OFFSET_riscv64_x11 104
+#define OFFSET_riscv64_x12 112
+#define OFFSET_riscv64_x13 120
+#define OFFSET_riscv64_x14 128
+#define OFFSET_riscv64_x15 136
+#define OFFSET_riscv64_x16 144
+#define OFFSET_riscv64_x17 152
+#define OFFSET_riscv64_x18 160
+#define OFFSET_riscv64_x19 168
+#define OFFSET_riscv64_x20 176
+#define OFFSET_riscv64_x21 184
+#define OFFSET_riscv64_x22 192
+#define OFFSET_riscv64_x23 200
+#define OFFSET_riscv64_x24 208
+#define OFFSET_riscv64_x25 216
+#define OFFSET_riscv64_x26 224
+#define OFFSET_riscv64_x27 232
+#define OFFSET_riscv64_x28 240
+#define OFFSET_riscv64_x29 248
+#define OFFSET_riscv64_x30 256
+#define OFFSET_riscv64_x31 264
+#define OFFSET_riscv64_pc 272
+#define OFFSET_riscv64_f0 280
+#define OFFSET_riscv64_f1 288
+#define OFFSET_riscv64_f2 296
+#define OFFSET_riscv64_f3 304
+#define OFFSET_riscv64_f4 312
+#define OFFSET_riscv64_f5 320
+#define OFFSET_riscv64_f6 328
+#define OFFSET_riscv64_f7 336
+#define OFFSET_riscv64_f8 344
+#define OFFSET_riscv64_f9 352
+#define OFFSET_riscv64_f10 360
+#define OFFSET_riscv64_f11 368
+#define OFFSET_riscv64_f12 376
+#define OFFSET_riscv64_f13 384
+#define OFFSET_riscv64_f14 392
+#define OFFSET_riscv64_f15 400
+#define OFFSET_riscv64_f16 408
+#define OFFSET_riscv64_f17 416
+#define OFFSET_riscv64_f18 424
+#define OFFSET_riscv64_f19 432
+#define OFFSET_riscv64_f20 440
+#define OFFSET_riscv64_f21 448
+#define OFFSET_riscv64_f22 456
+#define OFFSET_riscv64_f23 464
+#define OFFSET_riscv64_f24 472
+#define OFFSET_riscv64_f25 480
+#define OFFSET_riscv64_f26 488
+#define OFFSET_riscv64_f27 496
+#define OFFSET_riscv64_f28 504
+#define OFFSET_riscv64_f29 512
+#define OFFSET_riscv64_f30 520
+#define OFFSET_riscv64_f31 528
+#define OFFSET_riscv64_fcsr 536
