@@ -12,7 +12,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -213,7 +213,7 @@ void VG_(split_up_argv)( Int argc, HChar** argv )
    /* Should now be looking at the exe name. */
    if (i < argc) {
       vg_assert(argv[i]);
-      VG_(args_the_exename) = argv[i];
+      VG_(args_the_exename) = VG_(strdup)("commandline.sua.4", argv[i]);
       i++;
    }
 
