@@ -19,7 +19,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -1539,7 +1539,6 @@ static ULong DEBUG_SnarfLinetab(
    union any_size     pnt;
    union any_size     pnt2;
    const struct startend * start;
-   Int                this_seg;
 
    Bool  debug = di->trace_symtab;
    ULong n_lines_read = 0;
@@ -1563,7 +1562,6 @@ static ULong DEBUG_SnarfLinetab(
       pnt2.c = (const HChar *)linetab + filetab[i];
    }
 
-   this_seg = 0;
    for (i = 0; i < nfile; i++) {
       const HChar *fnmstr;
       const HChar *dirstr;
@@ -1601,7 +1599,7 @@ static ULong DEBUG_SnarfLinetab(
       fnmstr = ML_(addStr)(di, fnmstr, k);
       fnmdirstr_ix = ML_(addFnDn) (di, fnmstr, dirstr);
 
-      for (k = 0; k < file_segcount; k++, this_seg++) {
+      for (k = 0; k < file_segcount; k++) {
          Int linecount;
          Int segno;
 
