@@ -12,7 +12,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -768,7 +768,6 @@ extern UWord do_syscall_WRK (
           UWord a5,            /* %r9 */
           UWord a6,            /* 8(%rsp) */
           UWord a7,            /* 16(%rsp) */
-          UWord a8,            /* 24(%rsp) */
           UInt *flags,         /* 32(%rsp) */
           UWord *rv2           /* 40(%rsp) */
        );
@@ -784,20 +783,18 @@ asm(
 "      movq    %r8,  %r10\n"    /* a4 */
 "      movq    %r9,  %r8\n"     /* a5 */
 "      movq    16(%rbp), %r9\n" /* a6 last register arg from stack, account for %rbp */
-"      movq    32(%rbp), %r11\n" /* a8 from stack */
-"      pushq  %r11\n"
 "      movq    24(%rbp), %r11\n" /* a7 from stack */
-"      pushq  %r11\n"
+"      pushq   %r11\n"
 "      subq    $8,%rsp\n"       /* fake return addr */
 "      syscall\n"
 "      jb      1f\n"
-"      movq    48(%rbp),%rsi\n" /* success */
+"      movq    40(%rbp),%rsi\n" /* success */
 "      movq    %rdx, (%rsi)\n"  /* second return value */
 "      movq    %rbp, %rsp\n"
 "      popq    %rbp\n"
 "      ret\n"
 "1:\n"                          /* error path */
-"      movq    40(%rbp), %rsi\n" /* flags */
+"      movq    32(%rbp), %rsi\n" /* flags */
 "      movl    $1,(%rsi)\n"
 "      movq    %rbp, %rsp\n"
 "      popq    %rbp\n"
@@ -808,32 +805,31 @@ asm(
 #elif defined(VGP_arm64_freebsd)
 
 /*
- * Arguments a1 to a8 are in registers x0 to x7.
+ * Arguments a1 to a7 are in registers x0 to x6.
  * Which is just what we want for a syscall.
  *
- * The syscall number is on the top of the stack
- * pointed to by sp. The flags are at sp+8 and
- * second return value at sp+16.
+ * The syscall number is in x9
+ * The flags are at the top of the stack, sp and
+ * second return value at sp+8.
  */
 
 extern UWord do_syscall_WRK (
    UWord a1, UWord a2, UWord a3,
    UWord a4, UWord a5, UWord a6,
-   UWord a7, UWord a8,
-   UWord syscall_no,
+   UWord a7, UWord syscall_no,
    UInt *flags,  UWord *rv2
    );
 asm(
    ".text\n"
    ".globl do_syscall_WRK\n"
    "do_syscall_WRK:\n"
-   "        ldr  x8, [sp]\n"          // retrieve syscall_no, put it in x8
+   "        mov x8, x9\n"             // get the syscall number from x9
    "        svc  0x0\n"               // do the syscall
    "        mov  x9, 1\n"             // flags for error will be 1 or 0
    "        csel x9, x9, xzr, cs\n"   // conditionally select 1 or 0 into x9
-   "        ldr  x10, [sp, #8]\n"     // load the address of flags
+   "        ldr  x10, [sp]\n"         // load the address of flags
    "        str  w9, [x10]\n"         // store flags result
-   "        ldr  x10, [sp, #16]\n"    // load the addres of rv2
+   "        ldr  x10, [sp, #8]\n"     // load the addres of rv2
    "        str  x1, [x10]\n"         // store rv2 result
    "        ret\n"
    ".previous\n"
@@ -1231,7 +1227,7 @@ SysRes VG_(do_syscall) ( UWord sysno, RegWord a1, RegWord a2, RegWord a3,
    UWord val2 = 0;
    UInt err = 0;
    val = do_syscall_WRK(sysno, a1, a2, a3, a4, a5,
-                        a6, a7, a8, &err, &val2);
+                        a6, a7, &err, &val2);
    return VG_(mk_SysRes_amd64_freebsd)( val, val2, (err & 1) != 0 ? True : False);
 
 #  elif defined(VGP_arm64_freebsd)
@@ -1239,7 +1235,7 @@ SysRes VG_(do_syscall) ( UWord sysno, RegWord a1, RegWord a2, RegWord a3,
    UWord val2 = 0;
    UInt err = 0;
    val = do_syscall_WRK(a1, a2, a3, a4, a5,
-                        a6, a7, a8, sysno, &err, &val2);
+                        a6, a7, sysno, &err, &val2);
    return VG_(mk_SysRes_arm64_freebsd)( val, val2, (err & 1) != 0 ? True : False);
 
 #  elif defined(VGP_ppc32_linux)
