@@ -11,7 +11,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -551,6 +551,7 @@ PRE(sys_fstatat64)
         SARG1, ARG2, (HChar*)ARG2, ARG3, ARG4);
   PRE_REG_READ4(long, "fstatat64",
                  int, dfd, char *, file_name, struct stat64 *, buf, int, flags);
+  ML_(fd_at_check_allowed)(SARG1, (const HChar*)ARG2, "fstatat64", tid, status);
   PRE_MEM_RASCIIZ ("fstatat64(file_name)", ARG2);
   PRE_MEM_WRITE ("fstatat64(buf)", ARG3, sizeof (struct vki_stat64));
 }
@@ -826,7 +827,7 @@ static SyscallTableEntry syscall_main_table[] = {
    //..    //   (__NR_oldolduname,       sys_olduname),          // 59
    GENX_ (__NR_umask,                  sys_umask),                   // 60
    GENX_ (__NR_chroot,                 sys_chroot),                  // 61
-   //..    //   (__NR_ustat,             sys_ustat)              // 62
+   LINXY (__NR_ustat,                  sys_ustat),                   // 62
    GENXY (__NR_dup2,                   sys_dup2),                    // 63
    GENX_ (__NR_getppid,                sys_getppid),                 // 64
    GENX_ (__NR_getpgrp,                sys_getpgrp),                 // 65
@@ -851,7 +852,7 @@ static SyscallTableEntry syscall_main_table[] = {
    //..    //   (__NR_oldlstat,          sys_lstat),             // 84
    GENXY (__NR_readlink,               sys_readlink),                // 85
    //..    //   (__NR_uselib,            sys_uselib),            // 86
-   //..    //   (__NR_swapon,            sys_swapon),            // 87
+   LINX_ (__NR_swapon,                 sys_swapon),                  // 87
    //..    //   (__NR_reboot,            sys_reboot),            // 88
    //..    //   (__NR_readdir,           old_readdir),           // 89
    PLAX_ (__NR_mmap,                   sys_mmap),                    // 90
@@ -879,13 +880,13 @@ static SyscallTableEntry syscall_main_table[] = {
    //..    GENX_(__NR_idle,              sys_ni_syscall),        // 112
    //..    //   (__NR_vm86old,           sys_vm86old),           // 113
    GENXY (__NR_wait4,                  sys_wait4),                   // 114
-   //..    //   (__NR_swapoff,           sys_swapoff),           // 115
+   LINX_ (__NR_swapoff,                sys_swapoff),                 // 115
    LINXY (__NR_sysinfo,                sys_sysinfo),                 // 116
    LINXY (__NR_ipc,                    sys_ipc),                     // 117
    GENX_ (__NR_fsync,                  sys_fsync),                   // 118
    PLAX_ (__NR_sigreturn,              sys_sigreturn),               // 119
    LINX_ (__NR_clone,                  sys_clone),                   // 120
-   //..    //   (__NR_setdomainname,     sys_setdomainname),     // 121
+   LINX_ (__NR_setdomainname,          sys_setdomainname),           // 121
    GENXY (__NR_uname,                  sys_newuname),                // 122
    //..    PLAX_(__NR_modify_ldt,        sys_modify_ldt),        // 123
    LINXY (__NR_adjtimex,               sys_adjtimex),                // 124
@@ -899,7 +900,7 @@ static SyscallTableEntry syscall_main_table[] = {
    GENX_ (__NR_getpgid,                sys_getpgid),                 // 132
    GENX_ (__NR_fchdir,                 sys_fchdir),                  // 133
    //..    //   (__NR_bdflush,           sys_bdflush),           // 134
-   //..    //   (__NR_sysfs,             sys_sysfs),             // 135
+   LINXY (__NR_sysfs,                  sys_sysfs),                   // 135
    LINX_ (__NR_personality,            sys_personality),            // 136
    //..    GENX_(__NR_afs_syscall,       sys_ni_syscall),        // 137
    LINX_ (__NR_setfsuid,               sys_setfsuid),                // 138
@@ -1175,12 +1176,19 @@ static SyscallTableEntry syscall_main_table[] = {
    LINX_ (__NR_faccessat2,             sys_faccessat2),              // 439
 
    LINXY(__NR_epoll_pwait2,      sys_epoll_pwait2),      // 441
+   LINX_(__NR_mount_setattr,     sys_mount_setattr),     // 442
 
+   LINX_(__NR_quotactl_fd,             sys_quotactl_fd),             // 443
    LINXY(__NR_landlock_create_ruleset, sys_landlock_create_ruleset), // 444
    LINX_(__NR_landlock_add_rule,       sys_landlock_add_rule),       // 445
    LINX_(__NR_landlock_restrict_self,  sys_landlock_restrict_self),  // 446
+   LINX_(__NR_futex_waitv,             sys_futex_waitv),             // 449
 
+   LINXY(__NR_cachestat,               sys_cachestat),               // 451
    LINX_(__NR_fchmodat2,               sys_fchmodat2),               // 452
+   LINXY(__NR_statmount,               sys_statmount),               // 457
+   LINXY(__NR_listmount,               sys_listmount),               // 458
+   LINX_(__NR_mseal,                   sys_mseal),                   // 462
 };
 
 SyscallTableEntry* ML_(get_linux_syscall_entry) (UInt sysno)
