@@ -11,7 +11,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -215,12 +215,6 @@ SysRes sys_set_tls ( ThreadId tid, Addr tlsptr )
    file, but that requires even more macro magic. */
 
 DECL_TEMPLATE (mips_linux, sys_set_thread_area);
-DECL_TEMPLATE (mips_linux, sys_vmsplice);
-DECL_TEMPLATE (mips_linux, sys_ustat);
-DECL_TEMPLATE (mips_linux, sys_sysfs);
-DECL_TEMPLATE (mips_linux, sys_swapon);
-DECL_TEMPLATE (mips_linux, sys_swapoff);
-DECL_TEMPLATE (mips_linux, sys_setdomainname);
 DECL_TEMPLATE (mips_linux, sys_sethostname);
 DECL_TEMPLATE (mips_linux, sys_reboot);
 DECL_TEMPLATE (mips_linux, sys_cacheflush);
@@ -232,14 +226,6 @@ DECL_TEMPLATE (mips_linux, sys_rt_sigreturn);
 DECL_TEMPLATE (mips_linux, sys_pipe);
 DECL_TEMPLATE (mips_linux, sys_fadvise64);
 
-PRE(sys_vmsplice)
-{
-   PRINT("sys_vmsplice ( %ld, %#" FMT_REGWORD "x, %" FMT_REGWORD "u, %ld )",
-         SARG1, ARG2, ARG3, SARG4);
-   PRE_REG_READ4(long, "sys_vmsplice", int, fdin, struct vki_iovec *, v,
-                 vki_size_t, len, int, flags);
-}
-
 PRE(sys_sched_rr_get_interval)
 {
    PRINT("sys_sched_rr_get_interval ( %ld, %#" FMT_REGWORD "x)", SARG1, ARG2);
@@ -248,31 +234,6 @@ PRE(sys_sched_rr_get_interval)
    *flags |= SfMayBlock;
 }
 
-PRE(sys_ustat)
-{
-   PRINT("sys_ustat ( %#" FMT_REGWORD "x, %#" FMT_REGWORD "x)", ARG1, ARG2);
-   PRE_REG_READ2(long, "ustat", int, flags, const void *, path);
-}
-
-PRE(sys_swapon)
-{
-   PRINT("sys_swapon ( %#" FMT_REGWORD "x, %#" FMT_REGWORD "x )", ARG1, ARG2);
-   PRE_REG_READ2(long, "swapon", const void *, path, int, flags);
-}
-
-PRE(sys_swapoff)
-{
-   PRINT("sys_swapoff ( %#" FMT_REGWORD "x )", ARG1);
-   PRE_REG_READ1(long, "swapoff", const void *, path);
-}
-
-PRE(sys_sysfs)
-{
-   PRINT("sys_sysfs ( %ld, %#" FMT_REGWORD "x, %#" FMT_REGWORD "x )",
-         SARG1, ARG2, ARG3);
-   PRE_REG_READ3(long, "sysfs", int, flags, int, desc, const void *, path);
-}
-
 /* Very much MIPS specific */
 PRE(sys_cacheflush)
 {
@@ -297,12 +258,6 @@ PRE(sys_reboot)
    *flags |= SfMayBlock;
 }
 
-PRE(sys_setdomainname)
-{
-   PRINT ("sys_setdomainname ( %#" FMT_REGWORD "x, %ld )", ARG1, SARG2);
-   PRE_REG_READ2 (long, "setdomainname", const void *, name, int, len);
-}
-
 PRE(sys_sethostname)
 {
    PRINT ("sys_sethostname ( %#" FMT_REGWORD "x, %ld )", ARG1, SARG2);
@@ -649,10 +604,10 @@ static SyscallTableEntry syscall_main_table[] = {
    LINX_ (__NR_utime, sys_utime),
    GENX_ (__NR_mknod, sys_mknod),
    LINX_ (__NR_personality, sys_personality),
-   PLAX_ (__NR_ustat, sys_ustat),
+   LINXY (__NR_ustat, sys_ustat),
    GENXY (__NR_statfs, sys_statfs),
    GENXY (__NR_fstatfs, sys_fstatfs),
-   PLAX_ (__NR_sysfs, sys_sysfs),
+   LINXY (__NR_sysfs, sys_sysfs),
    GENX_ (__NR_getpriority, sys_getpriority),
    GENX_ (__NR_setpriority, sys_setpriority),
    LINXY (__NR_sched_setparam, sys_sched_setparam),
@@ -677,12 +632,13 @@ static SyscallTableEntry syscall_main_table[] = {
    GENX_ (__NR_acct, sys_acct),
    GENX_ (__NR_settimeofday, sys_settimeofday),
    LINX_ (__NR_mount, sys_mount),
+   LINX_ (__NR_mount_setattr, sys_mount_setattr),
    LINX_ (__NR_umount2, sys_umount),
-   PLAX_ (__NR_swapon, sys_swapon),
-   PLAX_ (__NR_swapoff, sys_swapoff),
+   LINX_ (__NR_swapon, sys_swapon),
+   LINX_ (__NR_swapoff, sys_swapoff),
    PLAX_ (__NR_reboot, sys_reboot),
    PLAX_ (__NR_sethostname, sys_sethostname),
-   PLAX_ (__NR_setdomainname, sys_setdomainname),
+   LINX_ (__NR_setdomainname, sys_setdomainname),
    GENX_ (__NR_create_module, sys_ni_syscall),
    LINX_ (__NR_init_module, sys_init_module),
    LINX_ (__NR_delete_module, sys_delete_module),
@@ -725,6 +681,7 @@ static SyscallTableEntry syscall_main_table[] = {
    LINXY (__NR_epoll_create1, sys_epoll_create1),
    LINX_ (__NR_epoll_ctl, sys_epoll_ctl),
    LINXY (__NR_epoll_wait, sys_epoll_wait),
+   LINX_ (__NR_remap_file_pages, sys_remap_file_pages),
    PLAX_(__NR_rt_sigreturn,sys_rt_sigreturn),
 #if defined(VGABI_N32)
    LINXY(__NR_fcntl64, sys_fcntl64),
@@ -780,7 +737,7 @@ static SyscallTableEntry syscall_main_table[] = {
    LINX_ (__NR_splice, sys_splice),
    LINX_ (__NR_sync_file_range, sys_sync_file_range),
    LINX_ (__NR_tee, sys_tee),
-   PLAX_ (__NR_vmsplice, sys_vmsplice),
+   LINXY (__NR_vmsplice, sys_vmsplice),
    LINX_ (__NR_set_robust_list, sys_set_robust_list),
    LINXY (__NR_get_robust_list, sys_get_robust_list),
    LINXY (__NR_epoll_pwait, sys_epoll_pwait),
@@ -835,8 +792,14 @@ static SyscallTableEntry syscall_main_table[] = {
    LINXY (__NR_landlock_create_ruleset, sys_landlock_create_ruleset),
    LINX_ (__NR_landlock_add_rule, sys_landlock_add_rule),
    LINX_ (__NR_landlock_restrict_self, sys_landlock_restrict_self),
+   LINXY (__NR_cachestat, sys_cachestat),
    LINX_ (__NR_fchmodat2, sys_fchmodat2),
    LINXY (__NR_userfaultfd, sys_userfaultfd),
+   LINXY (__NR_statmount, sys_statmount),
+   LINXY (__NR_listmount, sys_listmount),
+   LINX_ (__NR_mseal, sys_mseal),
+   LINX_ (__NR_futex_waitv, sys_futex_waitv),
+   LINX_ (__NR_quotactl_fd, sys_quotactl_fd),
 };
 
 SyscallTableEntry * ML_(get_linux_syscall_entry) ( UInt sysno )
