@@ -11,7 +11,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -45,7 +45,7 @@ extern Int  VG_(load_macho)  ( Int fd, const HChar *name, ExeInfo *info );
 #endif
 
 extern Bool VG_(match_script) ( const void *hdr, SizeT len );
-extern Int  VG_(load_script)  ( Int fd, const HChar *name, ExeInfo *info );
+extern Int  VG_(load_script)  ( Int fd, HChar *name, ExeInfo *info );
 
 
 #endif // __PRIV_UME_H
