@@ -12,7 +12,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -260,7 +260,7 @@ Bool waitstopped (pid_t pid, int signal_expected, const char *msg)
             ERROR(errno, "PT_LWPINFO failed: signal lost !!!!\n");
             signal_queue_sz--;
          } else {
-            DEBUG(1, "waitstopped PTRACE_CONT, queuing signal %d"
+            DEBUG(1, "waitstopped PTRACE_CONTINUE, queuing signal %d"
                   " si_signo %d si_pid %d\n",
                   signal_received, newsiginfo->si_signo, newsiginfo->si_pid);
          }
@@ -270,7 +270,7 @@ Bool waitstopped (pid_t pid, int signal_expected, const char *msg)
          res = ptrace (PT_CONTINUE, pid, (caddr_t)1, signal_received);
       }
       if (res != 0) {
-         ERROR(errno, "waitstopped PTRACE_CONT\n");
+         ERROR(errno, "waitstopped PTRACE_CONTINUE\n");
          return False;
       }
    }
@@ -392,7 +392,7 @@ void restore_and_detach (pid_t pid)
       if (signal_queue_sz > 0) {
          int i;
          for (i = 0; i < signal_queue_sz; i++) {
-            DEBUG(1, "PTRACE_CONT to transmit queued signal %d\n",
+            DEBUG(1, "PTRACE_CONTINUE to transmit queued signal %d\n",
                   signal_queue[i].si_signo);
             res = ptrace (PT_CONTINUE, pid_of_save_regs, (caddr_t)1,
                           signal_queue[i].si_signo);
@@ -561,6 +561,7 @@ Bool invoker_invoke_gdbserver (pid_t pid)
       reg_mod.r_rip = shared64->invoke_gdbserver;
 #elif defined(VGA_arm64)
       reg_mod.x[0] = check;
+      sp &= ~0xf; // keep the stack aligned on 16 bytes ...
       reg_mod.sp = sp;
       reg_mod.elr = shared64->invoke_gdbserver;
       /* put NULL return address in Link Register */
@@ -590,7 +591,7 @@ Bool invoker_invoke_gdbserver (pid_t pid)
    pid_of_save_regs_continued = False;
 
 
-   /* We PTRACE_CONT-inue pid.
+   /* We PTRACE_CONTINUE pid.
       Either gdbserver will be invoked directly (if all
       threads are interruptible) or gdbserver will be
       called soon by the scheduler. In the first case,
@@ -609,7 +610,7 @@ Bool invoker_invoke_gdbserver (pid_t pid)
    pid_of_save_regs_continued = True;
    /* Wait for SIGSTOP generated by m_gdbserver.c give_control_back_to_vgdb */
    stopped = waitstopped (pid, SIGSTOP,
-                          "waitpid status after PTRACE_CONT to invoke");
+                          "waitpid status after PTRACE_CONTINUE to invoke");
    if (stopped) {
       /* Here pid has properly stopped on the break. */
       pid_of_save_regs_continued = False;
