@@ -12,7 +12,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -21,9 +21,7 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307, USA.
+   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
    The GNU General Public License is contained in the file COPYING.
 */
@@ -77,7 +75,18 @@ void*        VG_(get_error_extra)   ( const Error* err );
    (see pub_tool_tooliface.h print_extra_suppression_info).
 
    If no 'a', 's' or 'extra' of interest needs to be recorded, just use
-   NULL for them.  */
+   NULL for them.
+
+   ATTENTION: 's' should not contain information that is (too) specific
+   to an instance of an error.  For example, 's' can clearly not contain
+   an address, as otherwise no way the user can build a suppression entry
+   matching such a variable error extra string.  It should preferrably not
+   contain offset or array indexes, for similar reason.
+   In other words, 's' should be NULL or should be a static string.
+   Finally, if you change the string 's' from one release to another
+   for the same error, you will introduce backward incompatible changes
+   with the suppression files produced for previous releases.
+   So, don't do that ! */
 extern void VG_(maybe_record_error) ( ThreadId tid, ErrorKind ekind,
                                       Addr a, const HChar* s, void* extra );
 
@@ -87,7 +96,9 @@ extern void VG_(maybe_record_error) ( ThreadId tid, ErrorKind ekind,
    'print_error' dictates whether to print the error, which is a bit of a
    hack that's useful sometimes if you just want to know if the error would
    be suppressed without possibly printing it.  'count_error' dictates
-   whether to add the error in the error total count (another mild hack). */
+   whether to add the error in the error total count (another mild hack).
+
+   ATTENTION: read the 'ATTENTION' above for VG_(maybe_record_error) ! */
 extern Bool VG_(unique_error) ( ThreadId tid, ErrorKind ekind,
                                 Addr a, const HChar* s, void* extra,
                                 ExeContext* where, Bool print_error,
