@@ -12,7 +12,7 @@
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
+   published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful, but
@@ -460,6 +460,9 @@
 #define __NR_set_mempolicy_home_node    (__NR_Linux + 450)
 #define __NR_cachestat                  (__NR_Linux + 451)
 #define __NR_fchmodat2                  (__NR_Linux + 452)
+#define __NR_statmount                  (__NR_Linux + 457)
+#define __NR_listmount                  (__NR_Linux + 458)
+#define __NR_mseal                      (__NR_Linux + 462)
 /*
  * Offset of the last Linux o32 flavoured syscall
  */
