@@ -152,10 +152,10 @@
 /* 32bit arm */
 #define CLEAR_CALLER_SAVED_REGS                                              \
    do {                                                                      \
-      __asm__ __volatile__ ("mov %r0, $0\n\t");                              \
-      __asm__ __volatile__ ("mov %r1, $0\n\t");                              \
-      __asm__ __volatile__ ("mov %r2, $0\n\t");                              \
-      __asm__ __volatile__ ("mov %r3, $0\n\t");                              \
+      __asm__ __volatile__ ("mov r0, $0\n\t");                              \
+      __asm__ __volatile__ ("mov r1, $0\n\t");                              \
+      __asm__ __volatile__ ("mov r2, $0\n\t");                              \
+      __asm__ __volatile__ ("mov r3, $0\n\t");                              \
    } while (0)
 #elif defined(__aarch64__)
 /* 64bit arm */
