@@ -1,5 +1,7 @@
 #include <stdio.h>
 #include <stdlib.h>
+#include <sys/types.h>
+#include <sys/time.h>
 #include <sys/resource.h>
 #include <unistd.h>
 
