@@ -1,4 +1,4 @@
-#if defined(__mips_hard_float)
+#if defined(__mips_hard_float) && (__mips_isa_rev<6)
 
 #include <stdio.h>
 
@@ -174,7 +174,6 @@ const double ft_d[] = {
 int main()
 {
    int i = 0;
-
    printf("--- BC1F ---  if fs != ft then " \
           "out = fs else out = fs + ft\n");
    for (i = 0; i < MAX_ARR; i++) {
